Canonicalizer
=============

.. currentmodule:: pyobo

.. autoclass:: Canonicalizer
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~Canonicalizer.cutoff
      ~Canonicalizer.priority

   .. rubric:: Methods Summary

   .. autosummary::

      ~Canonicalizer.all_shortest_paths
      ~Canonicalizer.canonicalize
      ~Canonicalizer.from_df
      ~Canonicalizer.get_default
      ~Canonicalizer.get_flat_mapping
      ~Canonicalizer.iterate_flat_mapping
      ~Canonicalizer.single_source_shortest_path

   .. rubric:: Attributes Documentation

   .. autoattribute:: cutoff
   .. autoattribute:: priority

   .. rubric:: Methods Documentation

   .. automethod:: all_shortest_paths
   .. automethod:: canonicalize
   .. automethod:: from_df
   .. automethod:: get_default
   .. automethod:: get_flat_mapping
   .. automethod:: iterate_flat_mapping
   .. automethod:: single_source_shortest_path
